==> moodle-1.4.3-pgsql.tgz: moodle/lang/fi/wiki.php <==
<?PHP // $Id$ 
      // wiki.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['action'] = '-- Toiminto --';
$string['administration'] = 'Yllpito';
$string['allowremovepages'] = 'Salli \'Poista sivuja\'';
$string['allowrevertchanges'] = 'Salli \'Peruuta muutokset\'';
$string['allowsetpage'] = 'Salli \'Aseta sivun liput\'';
$string['allowstrippages'] = 'Salli \'Siivoa sivuja\'';
$string['attachments'] = 'Sivun liitteet';
$string['author'] = 'Kirjoittaja';
$string['authorfieldpattern'] = 'Kirjoittajan ';
$string['authorfieldpatternerror'] = 'Anna kirjoittaja ole hyv.';
$string['backlinks'] = 'Viittaavat linkit';
$string['binimgtoolarge'] = 'Kuva on liian iso.';
$string['binnoimg'] = 'Tt tiedostomuotoa ei hyvksyt.';
$string['browse'] = 'Selaa';
$string['canceledit'] = 'Peruuta';
$string['cannotchangepage'] = 'Tt sivua ei voi muuttaa.';
$string['changes'] = '$a muutosta';
$string['changesfield'] = 'Kuinka monen tunnin sisll viime muutoksesta';
$string['changesfielderror'] = 'Ole hyv ja anna kelvollinen tuntimr';
$string['checklinks'] = 'Tarkista linkit';
$string['checklinkscheck'] = 'Oletko varma ett haluat tarkistaa linkit tlt sivulta:';
$string['checklinksnotice'] = 'Ole hyv ja odota rauhassa kun tm sivu latautuu';
$string['chooseadministration'] = '-- Yllpito --';
$string['chooseafile'] = 'Valitse/Lhet ensimminen sivu';
$string['choosewikilinks'] = '-- Valitse Wiki Linkit --';
$string['comment'] = 'Kommentti';
$string['contentsize'] = 'Sislln koko';
$string['created'] = 'Luotu';
$string['deletemewikiword'] = 'PoistaMinut';
$string['deletemewikiwordfound'] = '$a lytyi sivulta';
$string['deletepage'] = 'Poista sivu';
$string['deleteversions'] = 'Kuinka monta aikaisempaa versiota poistetaan';
$string['deleteversionserror'] = 'Ole hyv ja anna kelvollinen versioiden mr';
$string['diff'] = 'Erot';
$string['differences'] = 'Erot versioiden $a->new_ver ja $a->old_ver sivulla $a->pagename.';
$string['disablecamel'] = 'Est KameliKirjasinLinkittminen';
$string['disabledpage'] = 'Tm sivu ei ole tll hetkell saatavilla';
$string['doesnotexist'] = 'Tt sivua ei ole viel tehty, klikkaa Muokkaa-painiketta jos haluat luoda tmn sivun';
$string['downloadaszip'] = 'Ladattava zip-paketti';
$string['downloadtimes'] = 'Ladattu $a kertaa';
$string['dwnlnofiles'] = 'Tiedostoja ei ole viel lhetetty';
$string['dwnlsection'] = 'Ladattavat tiedostot';
$string['editform1'] = 'l murehdi liikaa tekstin muotoilua, voit muokata sivua aina jlkeenpin.';
$string['editform2'] = 'Muokkaa varovasti ja muista ett kaikki muokkaustapahtumat kirjataan yls.';
$string['editthispage'] = 'Muokkataan sivua';
$string['emptypage'] = 'Tyhj sivu';
$string['errorbinandtxt'] = 'Virhe: Sivu on tyypiltn BIN JA TXT';
$string['errorhtml'] = 'Sivu tyyppi HTML';
$string['errornotype'] = 'Virhe: Sivu ei ole tyypi  BIN EIK TXT';
$string['errororreason'] = 'Virhe tai syy';
$string['errorroandwr'] = 'Virhe: Sivu on Muokattava ja Kirjoitussuojattu';
$string['errorsize'] = 'Sivu on suurempi kuin 64k';
$string['errversionsave'] = 'Pahus, sill aikaa kun muokkasit sivua joku muu tallensi muuttuneen version. Palaa edelliselle sivulle ja kopioi tekemsi muutokset koneesi leikepydlle ja liit ne uudelleen sivulle.';
$string['ewikiacceptbinary'] = 'Salli binritiedostot';
$string['ewikiprinttitle'] = 'Pane wikinimi joka sivulle';
$string['export'] = 'Vie';
$string['exportformats'] = 'Vientimuodot';
$string['exportsuccessful'] = 'Vienti onnistui';
$string['exportto'] = 'Vie ';
$string['fetchback'] = 'Palauta';
$string['file'] = 'Tiedosto';
$string['filedownload'] = 'Tiedoston lataus';
$string['fileisoftype'] = 'Tiedosto on tyyppi';
$string['filtername'] = 'Wikisivun automaattilinkitys';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'Liput';
$string['flagsset'] = 'Liput muutettu';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['for'] = '->';
$string['forbidden'] = 'Sinulla ei ole oikeutta thn sivuun.';
$string['groups'] = 'Ryhmt';
$string['hits'] = '$a osumaa';
$string['howtooperate'] = 'Kuinka toimia';
$string['howtowiki'] = 'Kuinka kytt wiki';
$string['html'] = 'HTML-muotoilu';
$string['htmlmode'] = 'Sallittu HTML muotoilu';
$string['htmlonly'] = 'Vain HTML';
$string['index'] = 'Sislt';
$string['infoaboutpage'] = 'Tietoja tst sivusta';
$string['initialcontent'] = 'Valitse aloitussivu';
$string['invalidroot'] = 'Sinulla ei ole oikeutta sivuston etusivuun joten sivustokarttaa ei voi luoda.';
$string['lastchanged'] = 'Muokattu $a';
$string['lastmodified'] = 'Viimeisin muokkaus';
$string['linkdead'] = 'DEAD';
$string['linkok'] = 'OK';
$string['linkschecked'] = 'Linkki tarkastettu';
$string['listall'] = 'Listaa kaikki';
$string['listcandidates'] = 'Listaa ehdokkaat';
$string['meta'] = 'Meta tiedot';
$string['moduledirectory'] = 'Moduli hakemisto';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wikit';
$string['mostoftenchangedpages'] = 'Eniten muokatut sivut';
$string['mostvisitedpages'] = 'Eniten katsotut sivut';
$string['newestpages'] = 'Uusimmat sivut';
$string['noadministrationaction'] = 'Yllpito toimintoa ei annettu';
$string['nocandidatestoremove'] = 'Ei ehdotettavia sivuja poistettavaksi, valitse \'$a\' nhdksesi kaikki sivut';
$string['nochangestorevert'] = 'Ei muutoksia peruttavaksi';
$string['nohtml'] = 'Ei HTML';
$string['nolinksfound'] = 'Sivulta ei lytynyt linkkej';
$string['noregexp'] = 'Asetuksen  pit olla tysi merkkijono, et voi kytt * tai snnllisi lausekkeita (regex). Lis thn konee IP-osoite tai koneen nimi, mutta l porttia ( se vaihtuu aina joka yhteydess)';
$string['notadministratewiki'] = 'Sinulla ei ole tmn wikin yllpito-oikeuksia.';
$string['nothingtostrip'] = 'Ei sivuja joilla olisi useampi kuin yksi versio';
$string['nowikicreated'] = 'Thn wikiin ei ole luotu sivuja';
$string['of'] = '/';
$string['offline'] = 'OFFLINE';
$string['optional'] = 'Valinnainen';
$string['orphanedpage'] = 'Orposivu';
$string['orphanedpages'] = 'Orposivut';
$string['otherwikis'] = 'Muut wikit';
$string['ownerunknown'] = 'tuntematon';
$string['pageactions'] = 'Sivun toiminnot';
$string['pageindex'] = 'Sivun sislt';
$string['pageinfo'] = 'Sivun tiedot';
$string['pagename'] = 'Sivun nimi';
$string['pagenamechoice'] = '- tai -';
$string['pageslinkingto'] = 'Sivut jotka linkittvt thn sivuun';
$string['pagesremoved'] = 'Sivut poistettu';
$string['pagesreverted'] = 'Muutokset peruttu';
$string['pagesstripped'] = 'Sivut siivottu';
$string['plaintext'] = 'Pelkk teksti';
$string['preview'] = 'Esikatsele';
$string['readonly'] = 'Kirjoitusuojattu sivu';
$string['refs'] = 'Viittaukset';
$string['removenotice'] = 'Huomaa ett ainostaan orposivut ovat listattuna tss. Ja koska wiki testaa sivujen linkityksen vain osittain, voivat jotkut linkitetytkin sivut nky luettelossa.';
$string['removepagecheck'] = 'Oletko varma ett haluat poistaa nm sivut?';
$string['removepages'] = 'Poista sivuja';
$string['removeselectedpages'] = 'Poista valitut sivut';
$string['revertallsince'] = 'Poista mys muutokset jotka on tehty jlkeen';
$string['revertchanges'] = 'Peruuta muutokset';
$string['revertlastonly'] = 'Vain, jos se ainoa mahdollisuus';
$string['revertpages'] = 'Peruuta massamuutokset';
$string['revertpagescheck'] = 'Haluatko varmasti peruuttaa seuraavat muutokset:';
$string['revertthe'] = 'Poista vain valittu versio';
$string['safehtml'] = 'Turvallinen HTML';
$string['save'] = 'Tallenna';
$string['searchwiki'] = 'Etsi Wikist';
$string['setpageflags'] = 'Aseta sivun liput';
$string['sitemap'] = 'Sivukartta';
$string['smfor'] = 'Sivukartta';
$string['status'] = 'Tila';
$string['strippagecheck'] = 'Oletko varma ett haluat siivota vanhat versiot nilt sivuilta:';
$string['strippages'] = 'Siivoa sivuja';
$string['studentadminoptions'] = 'Opiskelijan yllpito-oikeudet';
$string['submit'] = 'Lhet';
$string['tabattachments'] = 'Liitteet';
$string['tabedit'] = 'Muokkaa';
$string['tabinfo'] = 'Historia';
$string['tablinks'] = 'Linkit';
$string['tabview'] = 'Katso';
$string['thanksforcontribution'] = 'Kiitokset osallistumisesta';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['thispageisntlinkedfromanywhereelse'] = 'Tt sivua ei ole linkitetty minnekn';
$string['updatedpages'] = 'Pivitetyt sivut';
$string['uplerror'] = 'Pahus, jotain meni pieleen tiedoston lhettmisess';
$string['uplinsect'] = 'Lhet';
$string['uplnewnam'] = 'Tallenna toisella nimell';
$string['upload0'] = 'Kyt tt lomaketta tiedostojen lhettmiseen:';
$string['uploadedon'] = 'Lhetetty';
$string['uploadpicturebutton'] = 'Lhet';
$string['uplok'] = 'Tiedostosi otettiin vastaan onnistuneesti';
$string['version'] = 'Versio';
$string['versionrangetoobig'] = 'Et voi poistaa sivun kaikkia versioita, viimeinen versio pit jtt.';
$string['versions'] = 'Versiot';
$string['versionstodelete'] = 'Poistettava(t) versio(t)';
$string['viewpage'] = 'Katso sivua';
$string['viewsmfor'] = 'Katso sivukarttaa';
$string['wantedpages'] = 'Halutut sivut';
$string['wikidefaultpagename'] = 'Wikin sislt';
$string['wikiexport'] = 'Vie sivuja';
$string['wikiexportcomment'] = 'Tss voit mritell vientiasetukset ';
$string['wikilinkoptions'] = 'Wikin automaattilinkitys mritykset';
$string['wikilinks'] = 'Wiki linkit';
$string['wikiname'] = 'Sivun nimi';
$string['wikistartederror'] = 'Wikiss on jo sivuja - ei voi muuttaa';
$string['wikitype'] = 'Tyyppi';
$string['wikiusage'] = 'Wikin kytt';
$string['withbinaries'] = 'Ota mukaan tiedostot';
$string['withvirtualpages'] = 'Ota mukaan Wiki-linkit';
$string['wrongversionrange'] = '$a ei ole kelvollinen alue.';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/fi/wiki.php <==
<?PHP // $Id$ 
      // wiki.php - created with Moodle 1.5.2 + (2005060222)


$string['action'] = '-- Toiminto --';
$string['administration'] = 'Yllpito';
$string['allowremovepages'] = 'Salli \'Poista sivuja\'';
$string['allowrevertchanges'] = 'Salli \'Peruuta muutokset\'';
$string['allowsetpage'] = 'Salli \'Aseta sivun liput\'';
$string['allowstrippages'] = 'Salli \'Siivoa sivuja\'';
$string['attachments'] = 'Sivun liitteet';
$string['author'] = 'Kirjoittaja';
$string['authorfieldpattern'] = 'Kirjoittajan ';
$string['authorfieldpatternerror'] = 'Anna kirjoittaja ole hyv.';
$string['backlinks'] = 'Viittaavat linkit';
$string['binimgtoolarge'] = 'Kuva on liian iso!';
$string['binnoimg'] = 'Tt tiedostomuotoa ei hyvksyt.';
$string['browse'] = 'Selaa';
$string['canceledit'] = 'Peruuta';
$string['cannotchangepage'] = 'Tt sivua ei voi muuttaa.';
$string['changes'] = '$a muutosta';
$string['changesfield'] = 'Kuinka monen tunnin sisll viime muutoksesta';
$string['changesfielderror'] = 'Ole hyv ja anna kelvollinen tuntimr';
$string['checklinks'] = 'Tarkista linkit';
$string['checklinkscheck'] = 'Oletko varma ett haluat tarkistaa linkit tlt sivulta:';
$string['checklinksnotice'] = 'Ole hyv ja odota rauhassa kun tm sivu latautuu';
$string['chooseadministration'] = '-- Yllpito --';
$string['chooseafile'] = 'Valitse/Lhet ensimminen sivu';
$string['choosewikilinks'] = '-- Valitse Wiki Linkit --';
$string['comment'] = 'Kommentti';
$string['contentsize'] = 'Sislln koko';
$string['created'] = 'Luotu';
$string['deletemewikiword'] = 'PoistaMinut';
$string['deletemewikiwordfound'] = '$a lytyi sivulta';
$string['deletepage'] = 'Poista sivu';
$string['deleteversions'] = 'Kuinka monta aikaisempaa versiota poistetaan';
$string['deleteversionserror'] = 'Ole hyv ja anna kelvollinen versioiden mr';
$string['diff'] = 'Erot';
$string['differences'] = 'Erot versioiden $a->new_ver ja $a->old_ver sivulla $a->pagename.';
$string['disablecamel'] = 'Est KameliKirjasinLinkittminen';
$string['disabledpage'] = 'Tm sivu ei ole tll hetkell saatavilla';
$string['doesnotexist'] = 'Tt sivua ei ole viel tehty, napsauta Muokkaa-painiketta jos haluat luoda tmn sivun';
$string['downloadaszip'] = 'Ladattava zip-paketti';
$string['downloadtimes'] = 'Ladattu $a kertaa';
$string['dwnlnofiles'] = 'Tiedostoja ei ole viel lhetetty';
$string['dwnlsection'] = 'Ladattavat tiedostot';
$string['editform1'] = 'l murehdi liikaa tekstin muotoilua, voit muokata sivua aina jlkeenpin.';
$string['editform2'] = 'Muokkaa varovasti ja muista ett kaikki muokkaustapahtumat kirjataan yls.';
$string['editthispage'] = 'Muokkataan sivua';
$string['emptypage'] = 'Tyhj sivu';
$string['errorbinandtxt'] = 'Virhe: Sivu on tyypiltn BIN JA TXT';
$string['errorhtml'] = 'Sivu tyyppi: HTML';
$string['errornotype'] = 'Virhe: Sivu ei ole tyypi  BIN EIK TXT';
$string['errororreason'] = 'Virhe tai syy';
$string['errorroandwr'] = 'Virhe: Sivu on Muokattava ja Kirjoitussuojattu';
$string['errorsize'] = 'Sivu on suurempi kuin 64k';
$string['errversionsave'] = 'Pahus, sill aikaa kun muokkasit sivua joku muu tallensi muuttuneen version. Palaa edelliselle sivulle ja kopioi tekemsi muutokset koneesi leikepydlle ja liit ne uudelleen sivulle.';
$string['ewikiacceptbinary'] = 'Salli binritiedostot';
$string['ewikiprinttitle'] = 'Pane wikinimi joka sivulle';
$string['export'] = 'Vie';
$string['exportformats'] = 'Vientimuodot';
$string['exportsuccessful'] = 'Vienti onnistui';
$string['exportto'] = 'Vie ';
$string['fetchback'] = 'Palauta';
$string['file'] = 'Tiedosto';
$string['filedownload'] = 'Tiedoston lataus';
$string['fileisoftype'] = 'Tiedosto on tyyppi';
$string['filtername'] = 'Wikisivun automaattilinkitys';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'Liput';
$string['flagsset'] = 'Liput muutettu';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['for'] = '->';
$string['forbidden'] = 'Sinulla ei ole oikeutta tulla tlle sivulle.';
$string['groups'] = 'Ryhmt';
$string['hits'] = '$a osumaa';
$string['howtooperate'] = 'Kuinka toimia';
$string['howtowiki'] = 'Kuinka kytt wiki';
$string['html'] = 'HTML-muotoilu';
$string['htmlmode'] = 'Sallittu HTML muotoilu';
$string['htmlonly'] = 'Vain HTML';
$string['index'] = 'Sislt';
$string['infoaboutpage'] = 'Tietoja tst sivusta';
$string['initialcontent'] = 'Valitse aloitussivu';
$string['invalidroot'] = 'Sinulla ei ole oikeutta sivuston etusivuun joten sivustokarttaa ei voi luoda.';
$string['lastchanged'] = 'Muokattu $a';
$string['lastmodified'] = 'Viimeisin muokkaus';
$string['linkdead'] = 'DEAD';
$string['linkok'] = 'OK';
$string['linkschecked'] = 'Linkit tarkastettu';
$string['listall'] = 'Listaa kaikki';
$string['listcandidates'] = 'Listaa ehdokkaat';
$string['meta'] = 'Meta tiedot';
$string['moduledirectory'] = 'Moduli hakemisto';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wikit';
$string['mostoftenchangedpages'] = 'Eniten muokatut sivut';
$string['mostvisitedpages'] = 'Eniten katsotut sivut';
$string['newestpages'] = 'Uusimmat sivut';
$string['noadministrationaction'] = 'Yllpito toimintoa ei annettu';
$string['nocandidatestoremove'] = 'Ei ehdotettavia sivuja poistettavaksi, valitse \'$a\' nhdksesi kaikki sivut';
$string['nochangestorevert'] = 'Ei muutoksia peruttavaksi';
$string['nohtml'] = 'Ei HTML';
$string['nolinksfound'] = 'Sivulta ei lytynyt linkkej';
$string['noregexp'] = 'Asetuksen  pit olla tysi merkkijono, et voi kytt * tai snnllisi lausekkeita (regex). Lis thn koneen IP-osoite tai koneen nimi, mutta l porttia ( se vaihtuu aina joka yhteydess)';
$string['notadministratewiki'] = 'Sinulla ei ole tmn wikin yllpito-oikeuksia.';
$string['nothingtostrip'] = 'Ei sivuja joilla olisi useampi kuin yksi versio';
$string['nowikicreated'] = 'Thn wikiin ei ole luotu sivuja';
$string['of'] = '/';
$string['offline'] = 'OFFLINE';
$string['optional'] = 'Valinnainen';
$string['orphanedpage'] = 'Orposivu';
$string['orphanedpages'] = 'Orposivut';
$string['otherwikis'] = 'Muut wikit';
$string['ownerunknown'] = 'tuntematon';
$string['pageactions'] = 'Sivun toiminnot';
$string['pageindex'] = 'Sivun sislt';
$string['pageinfo'] = 'Sivun tiedot';
$string['pagename'] = 'Sivun nimi';
$string['pagenamechoice'] = '- tai -';
$string['pageslinkingto'] = 'Sivut jotka linkittvt thn sivuun';
$string['pagesremoved'] = 'Sivut poistettu';
$string['pagesreverted'] = 'Muutokset peruttu';
$string['pagesstripped'] = 'Sivut siivottu';
$string['plaintext'] = 'Pelkk teksti';
$string['preview'] = 'Esikatsele';
$string['readonly'] = 'Kirjoitusuojattu sivu';
$string['refs'] = 'Viittaukset';
$string['removenotice'] = 'Huomaa ett ainostaan orposivut ovat listattuna tss. Ja koska wiki testaa sivujen linkityksen vain osittain, voivat jotkut linkitetytkin sivut nky luettelossa.';
$string['removepagecheck'] = 'Oletko varma ett haluat poistaa nm sivut?';
$string['removepages'] = 'Poista sivuja';
$string['removeselectedpages'] = 'Poista valitut sivut';
$string['revertallsince'] = 'Poista mys muutokset jotka on tehty jlkeen';
$string['revertchanges'] = 'Peruuta muutokset';
$string['revertlastonly'] = 'Vain, jos se ainoa mahdollisuus';
$string['revertpages'] = 'Peruuta massamuutokset';
$string['revertpagescheck'] = 'Haluatko varmasti peruuttaa seuraavat muutokset:';
$string['revertthe'] = 'Poista vain valittu versio';
$string['safehtml'] = 'Turvallinen HTML';
$string['save'] = 'Tallenna';
$string['searchwiki'] = 'Etsi Wikist';
$string['setpageflags'] = 'Aseta sivun liput';
$string['sitemap'] = 'Sivukartta';
$string['smfor'] = 'Sivukartta';
$string['status'] = 'Tila';
$string['strippagecheck'] = 'Oletko varma ett haluat siivota vanhat versiot nilt sivuilta:';
$string['strippages'] = 'Siivoa sivuja';
$string['studentadminoptions'] = 'Opiskelijan yllpito-oikeudet';
$string['submit'] = 'Lhet';
$string['tabattachments'] = 'Liitteet';
$string['tabedit'] = 'Muokkaa';
$string['tabinfo'] = 'Historia';
$string['tablinks'] = 'Linkit';
$string['tabview'] = 'Katso';
$string['thanksforcontribution'] = 'Kiitokset osallistumisesta';
$string['thispageisntlinkedfromanywhereelse'] = 'Tt sivua ei ole linkitetty minnekn';
$string['updatedpages'] = 'Pivitetyt sivut';
$string['updatedwikipages'] = 'Pivitettiin wiki-sivut';
$string['uplerror'] = 'Pahus, jotain meni pieleen tiedoston lhettmisess';
$string['uplinsect'] = 'Lhet';
$string['uplnewnam'] = 'Tallenna toisella nimell';
$string['upload0'] = 'Kyt tt lomaketta tiedostojen lhettmiseen:';
$string['uploadedon'] = 'Lhetetty';
$string['uploadpicturebutton'] = 'Lhet';
$string['uplok'] = 'Tiedostosi otettiin vastaan onnistuneesti';
$string['version'] = 'Versio';
$string['versionrangetoobig'] = 'Et voi poistaa sivun kaikkia versioita, viimeinen versio pit jtt.';
$string['versions'] = 'Versiot';
$string['versionstodelete'] = 'Poistettava(t) versio(t)';
$string['viewpage'] = 'Katso sivua';
$string['viewsmfor'] = 'Katso sivukarttaa';
$string['wantedpages'] = 'Halutut sivut';
$string['wikidefaultpagename'] = 'Wikin sislt';
$string['wikiexport'] = 'Vie sivuja';
$string['wikiexportcomment'] = 'Tss voit mritell vientiasetukset ';
$string['wikilinkoptions'] = 'Wikin automaattilinkitys mritykset';
$string['wikilinks'] = 'Wiki linkit';
$string['wikiname'] = 'Sivun nimi';
$string['wikistartederror'] = 'Wikiss on jo sivuja - ei voi muuttaa';
$string['wikitype'] = 'Tyyppi';
$string['wikiusage'] = 'Wikin kytt';
$string['withbinaries'] = 'Ota mukaan tiedostot';
$string['withvirtualpages'] = 'Ota mukaan Wiki-linkit';
$string['wrongversionrange'] = '$a ei ole kelvollinen alue.';

?>
